Update of /cvsroot/fink/dists/10.4/unstable/crypto/finkinfo
In directory sc8-pr-cvs17.sourceforge.net:/tmp/cvs-serv27039
Modified Files:
gnupg2.info
Added Files:
gnupg2.patch
Log Message:
Fix gnupg2 build on 10.5 (bool is now reserved)
Index: gnupg2.info
===================================================================
RCS file: /cvsroot/fink/dists/10.4/unstable/crypto/finkinfo/gnupg2.info,v
retrieving revision 1.3
retrieving revision 1.4
diff -u -d -r1.3 -r1.4
--- gnupg2.info 8 Nov 2007 06:47:24 -0000 1.3
+++ gnupg2.info 12 Nov 2007 03:41:10 -0000 1.4
@@ -22,6 +22,8 @@
Source2: mirror:sourceforge:fink/gnupg-docs-20021001.tar.gz
Source2-MD5: 5e34b5be84adc6a898e164b99fce45d8
Source2ExtractDir: gnupg-%v
+PatchFile: %n.patch
+PatchFile-MD5: 08fbc5f7a866905dbdedc1df30f74cdf
ConfigureParams: --libexecdir='${prefix}/lib' --with-libiconv-prefix=%p
--disable-dependency-tracking
InstallScript: <<
make install DESTDIR="%d"
--- NEW FILE: gnupg2.patch ---
bool is reserved on 10.5
diff --git a/g10/status.c b/g10/status.c
--- a/g10/status.c
+++ b/g10/status.c
@@ -385,10 +385,10 @@ myread(int fd, void *buf, size_t count)
/****************
* Request a string from the client over the command-fd
* If bool, returns static string on true (do not free) or NULL for false
*/
static char *
-do_get_from_fd( const char *keyword, int hidden, int bool )
+do_get_from_fd( const char *keyword, int hidden, int boolval )
{
int i, len;
char *string;
@@ -396,7 +396,7 @@ do_get_from_fd( const char *keyword, int
if(statusfp!=stdout)
fflush(stdout);
- write_status_text( bool? STATUS_GET_BOOL :
+ write_status_text( boolval? STATUS_GET_BOOL :
hidden? STATUS_GET_HIDDEN : STATUS_GET_LINE, keyword );
for( string = NULL, i = len = 200; ; i++ ) {
@@ -423,7 +423,7 @@ do_get_from_fd( const char *keyword, int
write_status( STATUS_GOT_IT );
- if( bool ) /* Fixme: is this correct??? */
+ if( boolval ) /* Fixme: is this correct??? */
return (string[0] == 'Y' || string[0] == 'y') ? "" : NULL;
return string;
-------------------------------------------------------------------------
This SF.net email is sponsored by: Splunk Inc.
Still grepping through log files to find problems? Stop.
Now Search log events and configuration files using AJAX and a browser.
@@ -385,10 +385,10 @@ myread(int fd, void *buf, size_t count)
/****************
* Request a string from the client over the command-fd
- * If bool, returns static string on true (do not free) or NULL for false
+ * If boolval, returns static string on true (do not free) or NULL for false
*/
static char *
Download your FREE copy of Splunk now >> http://get.splunk.com/
_______________________________________________
Fink-commits mailing list
[email protected]
http://news.gmane.org/gmane.os.apple.fink.cvs